@@ -59,7 +59,7 @@ Any executor inherited from :class:`BaseExecutor` always has the following **met
 
     .. confval:: on_gpu
 
-        indicates if the executor is running on GPU.
+        if the executor is set to run on GPU.
 
         :type: bool
         :default: ``False``
@@ -83,7 +83,7 @@ Any executor inherited from :class:`BaseExecutor` always has the following **met
 
     .. confval:: separated_workspace
 
-        whether to isolate the data of the replicas of this executor. If ``True``, then each replica works in its own
+        whether to isolate the data of the parallel of this executor. If ``True``, then each replica works in its own
         workspace specified in :attr:`replica_workspace`
 
         :type: bool
