@@ -1,9 +1,8 @@
-from .. import DeepSegmenter
-
-
 class TestClass:
     def test_deepsegmenter(self):
         """here is my test code
 
         https://docs.pytest.org/en/stable/getting-started.html#create-your-first-test
         """
+        # no test now
+        assert True
