@@ -10,7 +10,7 @@ def add_arg_group(parser, title):
 
 def set_base_parser():
     from .. import __version__
-    from ..helper import colored, get_full_version
+    from ..helper import colored, get_full_version, format_full_version_info
     # create the top-level parser
     urls = {
         'Jina 101': ('🐣', 'https://101.jina.ai'),
@@ -35,7 +35,7 @@ def set_base_parser():
                         help='show Jina version')
 
     parser.add_argument('-vf', '--version-full', action='version',
-                        version=get_full_version(),
+                        version=format_full_version_info(*get_full_version()),
                         help='show Jina and all dependencies versions')
     return parser
 
@@ -95,6 +95,12 @@ def set_hub_build_parser(parser=None):
                         help='downloads any updates to the FROM image in Dockerfiles')
     parser.add_argument('--push', action='store_true', default=False,
                         help='push the built image to the registry')
+    parser.add_argument('--dry-run', action='store_true', default=False,
+                        help='only check path and validility, no real building')
+    parser.add_argument('--prune-images', action='store_true', default=False,
+                        help='prune unused images after building, this often saves disk space')
+    parser.add_argument('--raise-error', action='store_true', default=False,
+                        help='raise any error and exit with code 1')
     return parser
 
 
